# if you make changes, the it is advised to increment this number, and provide
# a descriptive suffix to identify who owns or what the change represents
# e.g. release_version 2.MSW
%global release 1%{?dist}
%global _sharedstatedir /var/lib

# if you wish to build the server rpms, compile like this...
# rpmbuild -ta glusterfs-3.3.0rhs.tar.gz --with server
%if "%{?_with_server}"
%define _build_server 1
%else
%if "%{dist}" == ".el6rhs"
%define _build_server 1
%else
%define _build_server 0
%endif
%endif

# if you wish to compile an rpm without rdma support, compile like this...
# rpmbuild -ta glusterfs-3.3.0rhs.tar.gz --without rdma
%{?_without_rdma:%global _without_rdma --disable-ibverbs}

# No RDMA Support on x390(x)
%ifarch s390 s390x
%global _without_rdma --disable-ibverbs
%endif

# if you wish to compile an rpm without epoll...
# rpmbuild -ta glusterfs-3.3.0rhs.tar.gz --without epoll
%{?_without_epoll:%global _without_epoll --disable-epoll}

# if you wish to compile an rpm with fusermount...
# rpmbuild -ta glusterfs-3.3.0rhs.tar.gz --with fusermount
%{?_with_fusermount:%global _with_fusermount --enable-fusermount}

%global version 3.3.0.11rhs
%if "%{version}" >= "3.2"
%global _can_georeplicate 1

# if you wish to compile an rpm without geo-replication support, compile like this...
# rpmbuild -ta glusterfs-3.3.0rhs.tar.gz --without georeplication
%{?_without_georeplication:%global _without_georeplication --disable-geo-replication}
%endif

Summary: Cluster File System
Name: glusterfs
Version: %{version}
Release: %{release}
License: GPLv2 or LGPLv3+
Group: System Environment/Base
Vendor: Red Hat, Inc.
Packager: gluster-users@gluster.org
URL: http://www.gluster.org/docs/index.php/GlusterFS
Source0: glusterfs-%{version}.tar.gz
BuildRoot: %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/service, /sbin/chkconfig
Requires(postun): /sbin/service

BuildRequires: bison flex
BuildRequires: gcc make automake libtool
BuildRequires: ncurses-devel readline-devel openssl-devel
BuildRequires: libxml2-devel
BuildRequires: python-ctypes
%if 0%{?suse_version}
BuildRequires: python-devel
%endif
Requires: openssl

Obsoletes:        %{name}-libs <= 2.0.0
Obsoletes:        %{name}-common < %{version}-%{release}
Obsoletes:        %{name}-core < %{version}-%{release}
Provides:         %{name}-libs = %{version}-%{release}
Provides:         %{name}-common = %{version}-%{release}
Provides:         %{name}-core = %{version}-%{release}

%description
GlusterFS is a clustered file-system capable of scaling to several
peta-bytes. It aggregates various storage bricks over Infiniband RDMA
or TCP/IP interconnect into one large parallel network file
system. GlusterFS is one of the most sophisticated file system in
terms of features and extensibility.  It borrows a powerful concept
called Translators from GNU Hurd kernel. Much of the code in GlusterFS
is in userspace and easily manageable.

This package includes libraries and utility scripts.

%if 0%{!?_without_rdma:1}
%package rdma
Summary: GlusterFS rdma support for ib-verbs
License: GPLv2 or LGPLv3+
Group: Applications/File
BuildRequires: libibverbs-devel

Requires: %{name} = %{version}-%{release}

%description rdma
GlusterFS is a clustered file-system capable of scaling to several
peta-bytes. It aggregates various storage bricks over Infiniband RDMA
or TCP/IP interconnect into one large parallel network file
system. GlusterFS is one of the most sophisticated file system in
terms of features and extensibility.  It borrows a powerful concept
called Translators from GNU Hurd kernel. Much of the code in GlusterFS
is in userspace and easily manageable.

This package provides support to ib-verbs library.
%endif

%if 0%{?_build_server}
%if 0%{?_can_georeplicate}
%if 0%{!?_without_georeplication:1}
%package geo-replication
Summary: GlusterFS Geo-replication
License: GPLv3+
Group: Applications/File
Requires: %{name} = %{version}-%{release} , python-ctypes , rsync >= 3.0.0

%description geo-replication
GlusterFS is a clustered file-system capable of scaling to several
peta-bytes. It aggregates various storage bricks over Infiniband RDMA
or TCP/IP interconnect into one large parallel network file
system. GlusterFS is one of the most sophisticated file system in
terms of features and extensibility.  It borrows a powerful concept
called Translators from GNU Hurd kernel. Much of the code in GlusterFS
is in userspace and easily manageable.

This package provides support to geo-replication.
%endif
%endif
%endif

%package fuse
Summary: GlusterFS Fuse client
License: GPLv2 or LGPLv3+
Group: Applications/File

Requires: %{name} >= %{version}-%{release}

Obsoletes:        %{name}-client < %{version}-%{release}
Provides:         %{name}-client = %{version}-%{release}

%description fuse
GlusterFS is a clustered file-system capable of scaling to several
peta-bytes. It aggregates various storage bricks over Infiniband RDMA
or TCP/IP interconnect into one large parallel network file
system. GlusterFS is one of the most sophisticated file system in
terms of features and extensibility.  It borrows a powerful concept
called Translators from GNU Hurd kernel. Much of the code in GlusterFS
is in userspace and easily manageable.

This package provides support to FUSE based clients.

%if 0%{?_build_server}
%package server
Summary:          Clustered file-system server
License:          GPLv3+
Group:            System Environment/Daemons
Requires:         %{name} = %{version}-%{release}
Requires:         %{name}-fuse = %{version}-%{release}
Requires:         openssl
BuildRequires:    libaio-devel

%description server
GlusterFS is a clustered file-system capable of scaling to several
petabytes. It aggregates various storage bricks over Infiniband RDMA
or TCP/IP interconnect into one large parallel network file
system. GlusterFS is one of the most sophisticated file systems in
terms of features and extensibility.  It borrows a powerful concept
called Translators from GNU Hurd kernel. Much of the code in GlusterFS
is in user space and easily manageable.

This package provides the glusterfs server daemon and translators that
are loaded on the server.
%endif

%package devel
Summary:        Development Libraries
License:        GPLv2 or LGPLv3+
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}

%description devel
GlusterFS is a clustered file-system capable of scaling to several
petabytes. It aggregates various storage bricks over Infiniband RDMA
or TCP/IP interconnect into one large parallel network file
system. GlusterFS is one of the most sophisticated file systems in
terms of features and extensibility.  It borrows a powerful concept
called Translators from GNU Hurd kernel. Much of the code in GlusterFS
is in user space and easily manageable.

This package provides the development libraries.

%prep
%setup -q -n %{name}-%{version}

%build
./autogen.sh
%configure %{?_without_rdma} %{?_without_epoll} %{?_with_fusermount} %{?_without_georeplication}

# Remove rpath
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%{__make} %{?_smp_mflags}


%install
%{__rm} -rf %{buildroot}
%{__make} install DESTDIR=%{buildroot}
# Install include directory
%{__mkdir_p} %{buildroot}%{_includedir}/glusterfs
%{__install} -p -m 0644 libglusterfs/src/*.h \
    %{buildroot}%{_includedir}/glusterfs/
%{__install} -p -m 0644 contrib/uuid/*.h \
    %{buildroot}%{_includedir}/glusterfs/
# Following needed by hekafs multi-tenant translator
%{__mkdir_p} %{buildroot}%{_includedir}/glusterfs/rpc
%{__install} -p -m 0644 rpc/rpc-lib/src/*.h \
    %{buildroot}%{_includedir}/glusterfs/rpc/
%{__install} -p -m 0644 rpc/xdr/src/*.h \
    %{buildroot}%{_includedir}/glusterfs/rpc/
%{__mkdir_p} %{buildroot}%{_includedir}/glusterfs/server
%{__install} -p -m 0644 xlators/protocol/server/src/*.h \
    %{buildroot}%{_includedir}/glusterfs/server/
%{__mkdir_p} %{buildroot}%{_localstatedir}/run/gluster

# Remove unwanted files from all the shared libraries
find %{buildroot}%{_libdir} -name '*.a' -delete
find %{buildroot}%{_libdir} -name '*.la' -delete

# Remove installed docs, we include them ourselves as %%doc
%{__rm} -rf %{buildroot}%{_datadir}/doc/glusterfs/

# Rename the samples, so we can include them as %%config
#for file in %{buildroot}%{_sysconfdir}/glusterfs/*.sample; do
#  %{__mv} ${file} `dirname ${file}`/`basename ${file} .sample`
#done

# Create working directory
%{__mkdir_p} %{buildroot}%{_sharedstatedir}/glusterd

# Update configuration file to /var/lib working directory
sed -i 's|option working-directory /etc/glusterd|option working-directory %{_sharedstatedir}/glusterd|g' \
    %{buildroot}%{_sysconfdir}/glusterfs/glusterd.vol

%if 0%{?_build_server}
# Following needed by the hooks interface
subdirs=("add-brick" "create" "delete" "remove-brick" "set" "start" "stop")
for dir in ${subdirs[@]}
do
%{__mkdir_p} %{buildroot}%{_sharedstatedir}/glusterd/hooks/1/"$dir"/pre
%{__mkdir_p} %{buildroot}%{_sharedstatedir}/glusterd/hooks/1/"$dir"/post
done
%{__install} -p -m 0744 extras/hook-scripts/start/post/*.sh   \
    %{buildroot}%{_sharedstatedir}/glusterd/hooks/1/start/post
%{__install} -p -m 0744 extras/hook-scripts/stop/pre/*.sh   \
    %{buildroot}%{_sharedstatedir}/glusterd/hooks/1/stop/pre
%endif

# Clean up the examples we want to include as %%doc
#%{__cp} -a doc/examples examples
#%{__rm} -f examples/Makefile*

%if !0%{?_build_server}
echo "Removing files that are only used in the server subpackages."
rm %{buildroot}%{_sysconfdir}/glusterfs/glusterd.vol
rm %{buildroot}%{_sysconfdir}/init.d/glusterd
rm %{buildroot}%{_sbindir}/gluster
rm %{buildroot}%{_sbindir}/glusterd
rm %{buildroot}%{_libexecdir}/glusterfs/gsyncd
rm -rf %{buildroot}%{_libexecdir}/glusterfs/python/syncdaemon
%endif

%clean
%{__rm} -rf %{buildroot}

%post
/sbin/ldconfig

# Copy the 'glusterfs-logrotate' file at the right place
if [ -d /etc/logrotate.d ]; then
   cp %{_sysconfdir}/glusterfs/glusterfs-logrotate /etc/logrotate.d/glusterfs
fi

%postun
/sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING-GPLV2 COPYING-LGPLV3 INSTALL NEWS README THANKS
%config %{_sysconfdir}/glusterfs/glusterfs-logrotate
%config %{_sysconfdir}/glusterfs/group-virt.example
%{_libdir}/glusterfs
%{_libdir}/*.so.*
%{_sbindir}/glusterfs*
#%{_mandir}/man8/*gluster*.8*
%dir %{_localstatedir}/run/gluster
%dir %{_localstatedir}/log/glusterfs
%if 0%{!?_without_rdma:1}
%exclude %{_libdir}/glusterfs/%{version}/rpc-transport/rdma*
%endif
%exclude %{_libdir}/glusterfs/%{version}/xlator/mount/fuse*
%exclude %{_libdir}/glusterfs/%{version}/xlator/storage*
%exclude %{_libdir}/glusterfs/%{version}/xlator/features/posix*
%exclude %{_libdir}/glusterfs/%{version}/xlator/protocol/server*
%exclude %{_libdir}/glusterfs/%{version}/xlator/mgmt*
%exclude %{_libdir}/glusterfs/%{version}/xlator/nfs*

%if 0%{!?_without_rdma:1}
%files rdma
%defattr(-,root,root)
%{_libdir}/glusterfs/%{version}/rpc-transport/rdma*
%endif

%if 0%{?_build_server}
%if 0%{?_can_georeplicate}
%if 0%{!?_without_georeplication:1}
%post geo-replication
#restart glusterd.
%{_sysconfdir}/init.d/glusterd restart &> /dev/null

%files geo-replication
%defattr(-,root,root)
%{_libexecdir}/glusterfs/gsyncd
%{_libexecdir}/glusterfs/python/syncdaemon/*
%endif
%endif
%endif

%files fuse
%defattr(-,root,root)
%{_libdir}/glusterfs/%{version}/xlator/mount/fuse*
#%{_mandir}/man8/mount.glusterfs.8*
/sbin/mount.glusterfs
%if 0%{?_with_fusermount:1}
%{_bindir}/fusermount-glusterfs
%endif

%if 0%{?_build_server}
%post server
/sbin/chkconfig --add glusterd

# Move legacy sysconf files to the correct sysconfdir
if [ -d /etc/glusterd ]; then
    mkdir -p /var/lib
    mv /etc/glusterd /var/lib/
    ln -sf /var/lib/glusterd /etc/glusterd
fi

if [ -d /var/lib/glusterd/vols ]; then
    # Rename old volfiles in an RPM-standard way.  These aren't actually
    # considered package config files, so %config doesn't work for them.
    for file in $(find /var/lib/glusterd/vols -name '*.vol'); do
        newfile=${file}.rpmsave
        echo "warning: ${file} saved as ${newfile}"
        cp ${file} ${newfile}
    done
fi

# Need to copy the file.

mkdir -p /var/lib/glusterd/groups
cp %{_sysconfdir}/glusterfs/group-virt.example /var/lib/glusterd/groups/virt


pidof -c -o %PPID -x glusterd &> /dev/null
if [ $? -eq 0 ]; then
    kill -9 `pgrep -f gsyncd.py` &> /dev/null

    killall glusterd &> /dev/null
    #add marker translator
    glusterd --xlator-option *.upgrade=on -N
    glusterd
else
    glusterd --xlator-option *.upgrade=on -N
fi

%preun server
if [ $1 -eq 0 ]; then
    /sbin/service glusterd stop &>/dev/null || :
    /sbin/chkconfig --del glusterd
fi
if [ $1 -ge 1 ]; then
    /sbin/service glusterd condrestart &>/dev/null || :
fi

# Legacy server
if [ $1 -eq 0 ]; then
    /sbin/service glusterfsd stop &>/dev/null || :
    /sbin/chkconfig --del glusterfsd
fi
if [ $1 -ge 1 ]; then
    /sbin/service glusterfsd condrestart &>/dev/null || :
fi

%files server
%defattr(-,root,root,-)
#%doc examples/ doc/glusterfs*.vol.sample
%config(noreplace) %{_sysconfdir}/glusterfs
%{_sharedstatedir}/glusterd
%{_sysconfdir}/init.d/glusterd
%{_sbindir}/gluster
%{_sbindir}/glusterd
%{_libdir}/glusterfs/%{version}/xlator/storage*
%{_libdir}/glusterfs/%{version}/xlator/features/posix*
%{_libdir}/glusterfs/%{version}/xlator/protocol/server*
%{_libdir}/glusterfs/%{version}/xlator/mgmt*
%{_libdir}/glusterfs/%{version}/xlator/nfs*
%endif

%files devel
%defattr(-,root,root,-)
%{_includedir}/glusterfs
%exclude %{_includedir}/glusterfs/y.tab.h
%{_libdir}/*.so

%changelog
* Wed Jul  3 2013 Balamurugan Arumugam <barumuga@redhat.com> - 3.3.0.11rhs-1
- fixes rhbz#978802 rhbz#977250 rhbz#969224

* Wed May 29 2013 Vijay Bellur <vbellur@redhat.com> - 3.3.0.10rhs-1
- posix: Change default for batch-fsync-mode to reverse-fsync

* Fri May 24 2013 Vijay Bellur <vbellur@redhat.com> - 3.3.0.9rhs-1
- nfs: make NFS filehandles deterministic (bz966180)
- replicate: Improved transaction durability (bz928784)

* Tue May 21 2013 Amar Tumballi <atumball@redhat.com> - 3.3.0.8rhs-1
- root squash disable option (bz964032)
- selectively disable root-squash for trusted clients (bz961492)
- copy the uid/gid of the frame in quick-read xlator (bz961491)
- lockfile update in glusterd init file (bz958666)

* Wed Mar 20 2013 Amar Tumballi <atumball@redhat.com> - 3.3.0.7rhs-1
- Updated the version number of tarball to 3.3.0.7rhs

* Wed Mar 20 2013 Amar Tumballi <atumball@redhat.com> - 3.3.0.6rhs-6
- Updated the 'Changelog' in source tarball with 'git log' output
- No changes in source tree compared to 3.3.0.6rhs-5

* Wed Mar 20 2013 Amar Tumballi <atumball@redhat.com> - 3.3.0.6rhs-5
- distribute: fix the layout overlap calculation issue (bz884379)
- CLI: gluster rebalance/remove-brick stop message updated (bz919449)
- write-behind: performance regression fix with O_DIRECT (bz922578)
- nfs/replicate: EIO issues not to be propogated in lookup (bz921381)

* Thu Mar 14 2013 Raghavendra Bhat <rabhat@redhat.com> - 3.3.0.6rhs-4
- posix-acl: disable permission checks for fd based ops (bz918567)

* Fri Mar 08 2013 Amar Tumballi <atumball@redhat.com> - 3.3.0.6rhs-3
- distribute: proper layout setting when subvols-per-directory is used (bz917943)
- distribute: Preserve file size during rebalance migration (bz859589)
- distribute: don't span multiple crawler threads for rebalance (bz883853)
- Package /var/run/gluster so that statedumps can be created (bz917544)
- nlm: use appropriate open flags while locking (bz916595)

* Thu Feb 28 2013 Raghavendra Bhat <rabhat@redhat.com> - 3.3.0.6rhs-2
- Revert the distribute commit for preserving file size during rebalance migration

* Thu Feb 28 2013 Raghavendra Bhat <rabhat@redhat.com> - 3.3.0.6rhs-1
- distribute: Preserve file size during rebalance migration

* Tue Feb 19 2013 Raghavendra Bhat <rabhat@redhat.com> - 3.3.0.5rhs-43
- libglusterfs: Fix memory leans in locks insert and merge
- fuse: treat null gfid in lookup as a failure disregarding op_ret

* Mon Feb 18 2013 Raghavendra Bhat <rabhat@redhat.com> - 3.3.0.5rhs-42
- nfs/mount: get hostname of client to allow  fqdn based auth
- rpc: bring in root-squashing behavior
- nfs/nlm: use req's uid and gid for open_and_resume
- cluster/dht: ignore EEXIST error in mkdir to avoid GFID mismatch
- synctask: implement setuid-like SYNCTASK_SETID()

* Thu Feb 14 2013 Raghavendra Bhat <rabhat@redhat.com> - 3.3.0.5rhs-41
- writebehind: incorporate the changes from the upstream
- client: logging changes
- glusterfsd: fixed a crash in cleanup_and_exit
- distribute: If cached_subvol is down, return ENOTCONN in lookup
- distribute: hel directory uid/gid
- distribute: prevent layout overlaps
- server: properly handle the connections from rejected clients
- afr: handle failures in fop callbacks gracefully
- distribute: correct minimum free disk behavior
- nlm: use virtual ip of server to connect to client
- afr: link inode only on lookup
- posix: treat any value other that 0 from the syscall as a failure of that fop
- afr: fail read upon data split-brain

* Wed Dec 19 2012 Vijay Bellur  <vbellur@redhat.com> - 3.3.0.5rhs-40
- fuse: have setxattr on geo-rep related xattrs take effect
- logging: Improvements in afr and client protocols
- glusterd: Install group 'virt' as part of rpm  -i/U
- afr: make flush non-transactional
- distribute: fail fix-layout if bricks are not online
- locks: fcntl(3) on F_GETLK returns first conflicting lock

* Thu Dec 13 2012 Vijay Bellur  <vbellur@redhat.com> - 3.3.0.5rhs-39
- posix: Add support for aio.
- dht: Fix ownership issues in rebalance
- cli: xml improvements for peer status,
-      support for volume set group.
- fuse: gid caching implementation.
- glusterd: Add CIFS configuration support for RHS-C.
- afr: post-op delay support.
- new options added:
  gluster volume set <VOL> owner-uid <UID>
  gluster volume set <VOL> owner-gid <GID>
- gluster volume set <VOL> group virt
- fuse: Default the gid-timeout to 2
- glusterd: Addition of virt group template file
- write-behind: Implement causal ordering
- build: Install glusterfs-logrotate as a configuration file
- dht: Fix a crash in rebalance
- build: Install virt group file
- posix: O_DIRECT friendly changes for rchecksum fop
- distribute: cli support for setting directory-layout-spread
- new command added: gluster volume set <VOLNAME> remote-dio enable

* Thu Nov 15 2012 Vijay Bellur  <vbellur@redhat.com> - 3.3.0.5rhs-38
- nfs: do not fail writes when geo-replication is turned on
* Thu Nov 09 2012 Amar Tumballi  <atumball@redhat.com> - 3.3.0.5rhs-37
- fix a execstack issue with inner functions
* Wed Nov 07 2012 Amar Tumballi  <atumball@redhat.com> - 3.3.0.5rhs-36
- nfs: fix to handle link() failure (bz872923)
- quorum: handle quorum action on peer detach (bz862017)
* Fri Nov 01 2012 Vijay Bellur <vbellur@redhat.com> - 3.3.0.5rhs-35
- geo-replication: Fix to avoid status getting to N/A
* Fri Oct 19 2012 Vijay Bellur <vbellur@redhat.com> - 3.3.0.4rhs-34
- nfs: Perform lookup to trigger self-heal checks
* Wed Oct 10 2012 Amar Tumballi <atumball@redhat.com> - 3.3.0.3rhs-33
- valid hostname fix (bz863908)
- smb.conf init script issues (bz863907)
- geo-replication: rsync number of argument (bz859173)
* Mon Oct 01 2012 Amar Tumballi <atumball@redhat.com> - 3.3.0.3rhs-32
- bug fixes in quorum support
* Fri Sep 28 2012 Amar Tumballi <atumball@redhat.com> - 3.3.0.3rhs-31
- server side quorum support added
* Tue Sep 11 2012 Amar Tumballi <atumball@redhat.com> - 3.3.0.2rhs-29
- changing the upstream tarball version (no code difference from -28)
* Mon Sep 10 2012 Amar Tumballi <atumball@redhat.com> - 3.3.0-28
- glusterd: Fix a crash when volume status is issued
* Fri Sep 07 2012 Vijay Bellur <vbellur@redhat.com> - 3.3.0-27
- Improvements in GlusterFS statedump infrastructure
- glusterd, glusterfsd: Fix a crash when rpc submission fails
* Fri Aug 17 2012 Vijay Bellur <vbellur@redhat.com> - 3.3.0-26
- Updated to gluster 3.3.0-26 build
* Wed Jul 25 2012 Vijay Bellur <vbellur@redhat.com> - 3.3.0-25
- Updated to gluster 3.3.0-25 build
* Tue Jul 24 2012 Vijay Bellur <vbellur@redhat.com> - 3.3.0-24
- Updated to gluster 3.3.0-24 build
* Thu Jul 19 2012 Vijay Bellur <vbellur@redhat.com> - 3.3.0-23
- Updated to gluster 3.3.0-23 build
* Tue Jun 19 2012 Vijay Bellur <vbellur@redhat.com> - 3.3.0-22
- Updated to gluster 3.3.0-22 build
* Fri Jun 15 2012 Anthony Towns <atowns@redhat.com> - 3.3.0-21
- Allow building only native client packages.
* Thu Jun 14 2012 Vijay Bellur <vbellur@redhat.com> - 3.3.0-20
- Updated to gluster 3.3.0 build
* Wed May 30 2012 Vijay Bellur <vbellur@redhat.com> - 3.3.0qa45-1
- Updated to gluster 3.3 qa45 build
* Tue May 29 2012 Vijay Bellur <vbellur@redhat.com> - 3.3.0qa44-1
- Updated to gluster 3.3 qa44 build
* Wed May 23 2012 Vijay Bellur <vbellur@redhat.com> - 3.3.0qa43-1
- Updated to gluster 3.3 qa43 build
* Wed May 16 2012 Vijay Bellur <vbellur@redhat.com> - 3.3.0qa41-1
- Updated to gluster 3.3 qa41 build
* Tue May 08 2012 Anthony Towns <atowns@redhat.com> - 3.3.0qa40-1
- Updated to gluster 3.3 qa40 build
